Struct TypeOrigin
pub struct TypeOrigin {
pub module_name: Identifier,
pub datatype_name: Identifier,
pub package: ObjectId,
}Expand description
Stores the origin of a data type where it first appeared in the version chain. A data type is identified by the name of the module and the name of the struct/enum in combination.
BCS
The BCS serialized form for this type is defined by the following ABNF:
type-origin = identifier identifier object-idFields
module_name: IdentifierThe name of the module the data type resides in.
datatype_name: IdentifierThe name of the data type. Either refers to an enum or a struct identifier.
package: ObjectIdID of the package, where the given type first appeared.